| <font style="color:#ffffff;">物流状态</font> | <font style="color:#ffffff;">状态码</font> | <font style="color:#ffffff;">业务字段说明</font> |
| :--- | :--- | :--- |
| <font style="color:#000000;">暂无轨迹信息</font> | <font style="color:#000000;">0</font> | <font style="color:#000000;">货物暂无轨迹信息</font> |
| <font style="color:#000000;">已揽收</font> | <font style="color:#000000;">1</font> | <font style="color:#000000;">快递员已上门揽收快递</font> |
| <font style="color:#000000;">在途中</font> | <font style="color:#000000;">2</font> | <font style="color:#000000;">货物在途中运输</font> |
| <font style="color:#000000;">已签收</font> | <font style="color:#000000;">3</font> | <font style="color:#000000;">快件被签收</font> |
| <font style="color:#000000;">问题件</font> | <font style="color:#000000;">4</font> | <font style="color:#000000;">货物运输途中存在异常</font>（<font style="color:#585A5A;">若中途存在问题件，则后续轨迹将一直保持问题件状态</font>） |
| <font style="color:#000000;">转寄</font> | <font style="color:#000000;">5</font> | <font style="color:#000000;">快递被转寄到新地址</font> |




